@@ -14,9 +14,6 @@
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
-/* $Id: RequestInfoExample.java 1200123 2011-11-10 04:03:27Z kkolinko $
- *
- */
 
 import java.io.IOException;
 import java.io.PrintWriter;
@@ -50,7 +47,6 @@ public class RequestInfoExample extends HttpServlet {
 
         PrintWriter out = response.getWriter();
         out.println("<html>");
-        out.println("<body>");
         out.println("<head>");
 
         String title = RB.getString("requestinfo.title");
@@ -76,7 +72,7 @@ public class RequestInfoExample extends HttpServlet {
         out.println("<table border=0><tr><td>");
         out.println(RB.getString("requestinfo.label.method"));
         out.println("</td><td>");
-        out.println(request.getMethod());
+        out.println(HTMLFilter.filter(request.getMethod()));
         out.println("</td></tr><tr><td>");
         out.println(RB.getString("requestinfo.label.requesturi"));
         out.println("</td><td>");
@@ -84,28 +80,28 @@ public class RequestInfoExample extends HttpServlet {
         out.println("</td></tr><tr><td>");
         out.println(RB.getString("requestinfo.label.protocol"));
         out.println("</td><td>");
-        out.println(request.getProtocol());
+        out.println(HTMLFilter.filter(request.getProtocol()));
         out.println("</td></tr><tr><td>");
         out.println(RB.getString("requestinfo.label.pathinfo"));
         out.println("</td><td>");
         out.println(HTMLFilter.filter(request.getPathInfo()));
         out.println("</td></tr><tr><td>");
         out.println(RB.getString("requestinfo.label.remoteaddr"));
+        out.println("</td><td>");
+        out.println(HTMLFilter.filter(request.getRemoteAddr()));
+        out.println("</td></tr>");
 
         String cipherSuite=
-            (String)request.getAttribute("javax.servlet.request.cipher_suite");
-        out.println("</td><td>");
-        out.println(request.getRemoteAddr());
-        out.println("</table>");
-
+                (String)request.getAttribute("javax.servlet.request.cipher_suite");
         if(cipherSuite!=null){
-            out.println("</td></tr><tr><td>");
+            out.println("<tr><td>");
             out.println("SSLCipherSuite:");
-            out.println("</td>");
-            out.println("<td>");
-            out.println(request.getAttribute("javax.servlet.request.cipher_suite"));
-            out.println("</td>");
+            out.println("</td><td>");
+            out.println(HTMLFilter.filter(cipherSuite));
+            out.println("</td></tr>");
         }
+
+        out.println("</table>");
     }
 
     @Override
